@@ -10,7 +10,7 @@ our @ISA = qw(Exporter);
 our @EXPORT = qw(mime_exec mime_system);
 our @EXPORT_OK = qw(suggest_script_name);
 our %EXPORT_TAGS = (magic => \@EXPORT);
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 our @choicespath = (
 	config_home('rox.sourceforge.net'),
 	File::Spec->catdir($ENV{HOME}, 'Choices'),
@@ -19,7 +19,7 @@ our @choicespath = (
 our ($DEBUG);
 
 sub import {
-	my $parent = (grep {$_ eq q/:magic/} @_) 
+	my $parent = (grep {$_ eq q/:magic/} @_)
 		? q/File::MimeInfo::Magic/
 		: q/File::MimeInfo/;
 	eval "use $parent";
@@ -41,7 +41,7 @@ sub _do_mime {
 	return undef unless $script;
 
 	print "Going to $act: $script $file\n" if $DEBUG;
-	($act eq 'exec') 
+	($act eq 'exec')
 		? exec($script, $file, @_)
 		: (system($script, $file, @_) == 0)
 			or croak "couldn't $act: $script $file";
@@ -53,11 +53,11 @@ sub _locate_script {
 	$mime =~ /^(\w+)/;
 	my $media = $1;
 	$mime =~ s#/#_#;
-	my @p = $ENV{CHOICESPATH} 
-		? split(/:/, $ENV{CHOICESPATH}) 
+	my @p = $ENV{CHOICESPATH}
+		? split(/:/, $ENV{CHOICESPATH})
 		: (@choicespath);
 	my $script;
-	for ( 
+	for (
 		map("$_/MIME-types/$mime", @p),
 		map("$_/MIME-types/$media", @p)
 	) {
@@ -92,7 +92,7 @@ File::MimeInfo::Rox - Open files by mimetype "Rox style"
 
   use File::MimeInfo::Magic;
   use File::MimeInfo::Rox qw/:magic/;
-  
+
   # open some file with the apropriate program
   mime_system($somefile);
 
@@ -115,14 +115,14 @@ mechanism.
 
 =head1 EXPORT
 
-The methods C<mime_exec> and C<mime_system> are exported, 
+The methods C<mime_exec> and C<mime_system> are exported,
 if you use the export tag C<:magic> you get the same methods
 but L<File::MimeInfo::Magic> will be used for mimetype lookup.
 
 =head1 ENVIRONMENT
 
 The environment variable C<CHOICESPATH> is used when searching
-for rox's config dirs. It defaults to 
+for rox's config dirs. It defaults to
 C<$ENV{HOME}/Choices:/usr/local/share/Choices:/usr/share/Choices>
 
 =head1 METHODS
@@ -165,9 +165,9 @@ Please mail the author when you encounter any bugs.
 
 =head1 AUTHOR
 
-Jaap Karssenberg || Pardus [Larus] E<lt>pardus@cpan.orgE<gt>
+Jaap Karssenberg E<lt>pardus@cpan.orgE<gt>
 
-Copyright (c) 2003,2008 Jaap G Karssenberg. All rights reserved.
+Copyright (c) 2003, 2012 Jaap G Karssenberg. All rights reserved.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
